abacusai.module — AbacusAI documentation

# abacusai.module

## Classes

`Module` | Customer created python module

## Module Contents

class abacusai.module.Module(client, name=None, createdAt=None, notebookId=None, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  Customer created python module

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - name (str) – The name to identify the algorithm. Only uppercase letters, numbers, and underscores are allowed.

    - createdAt (str) – The date and time when the Python function was created, in ISO-8601 format.

    - notebookId (str) – The unique string identifier of the notebook used to create or edit the module.

    - codeSource (CodeSource) – Information about the source code of the Python function.

  name
  created_at
  notebook_id
  code_source
  deprecated_keys
  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict